==> 0.0.18.tar.gz: lib/layout/bmi_app.dart <==
import 'package:bmi_global/utils/user.dart';
import 'package:flutter/material.dart';
import 'package:bmi_global/layout/gateway.dart';
import 'package:bmi_global/layout/route.dart';
import 'package:bmi_global/provider/auth.dart';
import 'package:bmi_global/provider/config.dart';
import 'package:bmi_global/provider/app_info.dart';
import 'package:bmi_global/utils/proceed.dart';
import 'package:provider/provider.dart';

class BmiApp<U extends AuthUser, A extends AuthProvider<U>, R extends AppRoute,
    I extends AppInfoProvider> extends StatelessWidget {
  const BmiApp({
    Key? key,
    required this.authProvider,
    required this.appInfoProvider,
    required this.initialMode,
    required this.onThemeModeChange,
    required this.page404Builder,
    required this.defaultRoute,
    required this.finalGateway,
  }) : super(key: key);
  final A Function(BuildContext) authProvider;
  final I Function(BuildContext) appInfoProvider;
  final ThemeMode? initialMode;
  final void Function(ThemeMode) onThemeModeChange;
  final Widget Function(BuildContext) page404Builder;
  final R defaultRoute;
  final Widget Function(BuildContext, Widget) finalGateway;
  @override
  Widget build(BuildContext context) {
    return MultiProvider(
      providers: [
        ChangeNotifierProvider(
          create: (context) => ConfigProvider(
            initialMode ?? ThemeMode.system,
            onThemeModeChange,
            build404Page: page404Builder,
            defaultRoute: defaultRoute,
            finalGateway: finalGateway,
          ),
          lazy: false,
        ),
        ChangeNotifierProvider(create: appInfoProvider, lazy: false),
        ChangeNotifierProvider(create: authProvider, lazy: false),
      ],
      child: _App<U, A, R, I>(),
    );
  }
}

class _App<U extends AuthUser, A extends AuthProvider<U>, R extends AppRoute,
    I extends AppInfoProvider> extends StatelessWidget {
  const _App({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final configProvider = Provider.of<ConfigProvider>(context);
    return MaterialApp(
      title: 'B2B',
      themeMode: configProvider.themeMode,
      theme: ThemeData.light(),
      darkTheme: ThemeData.dark(),
      initialRoute: configProvider.defaultRoute.route,
      onUnknownRoute: (RouteSettings settings) {
        return PageRouteBuilder(
          pageBuilder: (context, _, __) {
            return Provider(
              create: (context) => settings,
              child: configProvider.build404Page(context),
            );
          },
          transitionDuration: const Duration(milliseconds: 200),
          reverseTransitionDuration: const Duration(milliseconds: 100),
          transitionsBuilder: (_, a, __, c) {
            return FadeTransition(opacity: a, child: c);
          },
        );
      },
      onGenerateRoute: (RouteSettings settings) {
        final route = settings.name;
        final appRoute = appRouteFromRoute(route);
        if (appRoute == null) return null;
        final page = appRoute.builder(context, argument: settings.arguments);
        if (page == null) return null;
        if (appRoute.isMainPage) {
          return PageRouteBuilder(
            pageBuilder: (context, _, __) {
              return WillPopScope(
                onWillPop: () async {
                  if (Navigator.canPop(context)) return true;
                  return await proceed(
                    context,
                    "Exit App",
                    "Sure, you want to Exit?",
                  );
                },
                child: Provider(
                  create: (context) => settings,
                  child: page,
                ),
              );
            },
            transitionDuration: const Duration(milliseconds: 250),
            reverseTransitionDuration: const Duration(milliseconds: 150),
            transitionsBuilder: (_, a, __, c) {
              return FadeTransition(opacity: a, child: c);
            },
          );
        } else {
          return MaterialPageRoute(
            builder: (context) {
              return Provider(
                create: (_) => settings,
                child: page,
              );
            },
          );
        }
      },
      builder: GateWayPage<U, A, R, I>.build,
    );
  }
}

==> 0.0.21.tar.gz: lib/layout/bmi_app.dart <==
import 'package:bmi_global/utils/user.dart';
import 'package:flutter/material.dart';
import 'package:bmi_global/layout/gateway.dart';
import 'package:bmi_global/layout/route.dart';
import 'package:bmi_global/provider/auth.dart';
import 'package:bmi_global/provider/config.dart';
import 'package:bmi_global/provider/app_info.dart';
import 'package:bmi_global/utils/proceed.dart';
import 'package:provider/provider.dart';

class BmiApp<U extends AuthUser, R extends AppRoute> extends StatelessWidget {
  const BmiApp({
    Key? key,
    required this.authProvider,
    required this.appInfoProvider,
    required this.configProvider,
  }) : super(key: key);
  final AuthProvider<U> authProvider;
  final AppInfoProvider appInfoProvider;
  final ConfigProvider configProvider;
  @override
  Widget build(BuildContext context) {
    return MultiProvider(
      providers: [
        ChangeNotifierProvider(create: (context) => configProvider),
        ChangeNotifierProvider(create: (_) => appInfoProvider),
        ChangeNotifierProvider(create: (_) => authProvider),
      ],
      child: _App<U>(),
    );
  }
}

class _App<U extends AuthUser> extends StatelessWidget {
  const _App({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final configProvider = Provider.of<ConfigProvider>(context);
    return MaterialApp(
      title: 'B2B',
      themeMode: configProvider.themeMode,
      theme: ThemeData.light(),
      darkTheme: ThemeData.dark(),
      initialRoute: configProvider.defaultRoute.route,
      onUnknownRoute: (RouteSettings settings) {
        return PageRouteBuilder(
          pageBuilder: (context, _, __) {
            return Provider(
              create: (context) => settings,
              child: configProvider.build404Page(context),
            );
          },
          transitionDuration: const Duration(milliseconds: 200),
          reverseTransitionDuration: const Duration(milliseconds: 100),
          transitionsBuilder: (_, a, __, c) {
            return FadeTransition(opacity: a, child: c);
          },
        );
      },
      onGenerateRoute: (RouteSettings settings) {
        final route = settings.name;
        final appRoute = appRouteFromRoute(route);
        if (appRoute == null) return null;
        final page = appRoute.builder(context, argument: settings.arguments);
        if (page == null) return null;
        if (appRoute.isMainPage) {
          return PageRouteBuilder(
            pageBuilder: (context, _, __) {
              return WillPopScope(
                onWillPop: () async {
                  if (Navigator.canPop(context)) return true;
                  return await proceed(
                    context,
                    "Exit App",
                    "Sure, you want to Exit?",
                  );
                },
                child: Provider(
                  create: (context) => settings,
                  child: page,
                ),
              );
            },
            transitionDuration: const Duration(milliseconds: 250),
            reverseTransitionDuration: const Duration(milliseconds: 150),
            transitionsBuilder: (_, a, __, c) {
              return FadeTransition(opacity: a, child: c);
            },
          );
        } else {
          return MaterialPageRoute(
            builder: (context) {
              return Provider(
                create: (_) => settings,
                child: page,
              );
            },
          );
        }
      },
      builder: GateWayPage<U>.build,
    );
  }
}
